import random as r

Poets = ["""
내가 그때 만약
                    -LJW

내가 그때 만약
그 편의점을 들어갔더라면
결과가 달랐을까요?

내가 그때 만약
네게 인사를 했더라면
우리는 이루어 졌을까요?

내가 그때 만약
너를 만나지 않았더라면
과연 이런 고민 했을까요?

우우우

인생은 타이밍
사랑도 타이밍
너와 나의 인연
""",
       f"""
벚꽃
	-LJW

봄이 왔다

길고
끝나지 않을것 같던
겨울이 끝나고

봄이 왔다

사람들은 봄이
희망의 계절이라 말한다

새들이 지저귀고
파릇한 식물들이 자라나는
희망찬 봄날에

나는 {r.choice(["헤어졌", "차였"])}다


벚꽃
다 떨어져버려라

빨리 겨울이 오길
""",
"""
카톡
        -LJW

그녀에게
갑작스런 카톡이 왔다

따뜻하던 봄날에
날 찬 그녀가

역시 아이폰 짱이다

그녀가 보낸 내용을
미리보기에서
모두 볼 수 있다니

새로운 사랑을
찾아나선 그녀가
차였다고 한다

축하해줄까,
위로해줄까?

읽씹하기로 했다.
""",
"""
IDC
	-LJW

네가 뭘하든
내겐,
IDC

네가 내 앞에서
재롱을 떨어도
난 IDC

겉으로는
I Don't Care,
속으로는
I DO Care
""",
"""
썸
	-LJW

'썸'이란건
서로 가까이 다가갔다가
또 엇갈리다가
다음 날이면 원점으로 돌아가는 관계

친구 이상
애인 미만

'썸'이란건
아무리 신호를 주고 정답을 알려줘도
확신을 할 수 없는 관계
마음이 자꾸 불안한 관계

친구 이상
애인 미만

가깝지만 닿지 않는
한 뼘의 거리
""",
"""
너가 그리워지는 밤
		-LJW

잘 지냈니
그날 밤 우리의 이별
그땐 몰랐지
이제는 너와 따뜻한 얘기를 할 수 없단걸
모든게 지나가는 일인줄 알았지

기억나니
우리가 처음 만났던 그날
그땐 모든게 좋았지
너와 어여쁜 사랑을 할 수 있다는 사실이
나에게는 하루하루의 목표였어

혜성처럼 나타났다가
빛의 속도로 달아난 너가

원망스러워
아니
사실은 원망스럽지 않아
"""]

class LJW(object):
  def __init__(self, Poets=Poets):
    self.Name = "이재우"
    self.Poets = Poets

  def random():
    print(r.choice(Poets))

  def all():
    for i in Poets:
      print(i)
      print("\n")



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="LJW",
    version="0.0.1",
    author="Jaewoo Lee",
    author_email="doni04164@gmail.com",
    description="Korean poets written by LJW",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jaewoo4200/poem_LJW",
    python_requires = '>=3.7',
    packages=['poems'],
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
